==> google-cloud-dialogflow-2.14.1.tar.gz: google-cloud-dialogflow-2.14.1/google/cloud/dialogflow_v2beta1/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .agent import (
    Agent,
    DeleteAgentRequest,
    ExportAgentRequest,
    ExportAgentResponse,
    GetAgentRequest,
    GetValidationResultRequest,
    ImportAgentRequest,
    RestoreAgentRequest,
    SearchAgentsRequest,
    SearchAgentsResponse,
    SetAgentRequest,
    SubAgent,
    TrainAgentRequest,
)
from .answer_record import (
    AgentAssistantFeedback,
    AgentAssistantRecord,
    AnswerFeedback,
    AnswerRecord,
    GetAnswerRecordRequest,
    ListAnswerRecordsRequest,
    ListAnswerRecordsResponse,
    UpdateAnswerRecordRequest,
)
from .audio_config import (
    InputAudioConfig,
    OutputAudioConfig,
    SpeechContext,
    SpeechToTextConfig,
    SpeechWordInfo,
    SynthesizeSpeechConfig,
    TelephonyDtmfEvents,
    VoiceSelectionParams,
    AudioEncoding,
    OutputAudioEncoding,
    SpeechModelVariant,
    SsmlVoiceGender,
    TelephonyDtmf,
)
from .context import (
    Context,
    CreateContextRequest,
    DeleteAllContextsRequest,
    DeleteContextRequest,
    GetContextRequest,
    ListContextsRequest,
    ListContextsResponse,
    UpdateContextRequest,
)
from .conversation import (
    BatchCreateMessagesRequest,
    BatchCreateMessagesResponse,
    CompleteConversationRequest,
    Conversation,
    ConversationPhoneNumber,
    CreateConversationRequest,
    CreateMessageRequest,
    GetConversationRequest,
    ListConversationsRequest,
    ListConversationsResponse,
    ListMessagesRequest,
    ListMessagesResponse,
)
from .conversation_event import (
    ConversationEvent,
)
from .conversation_profile import (
    AutomatedAgentConfig,
    ClearSuggestionFeatureConfigOperationMetadata,
    ClearSuggestionFeatureConfigRequest,
    ConversationProfile,
    CreateConversationProfileRequest,
    DeleteConversationProfileRequest,
    GetConversationProfileRequest,
    HumanAgentAssistantConfig,
    HumanAgentHandoffConfig,
    ListConversationProfilesRequest,
    ListConversationProfilesResponse,
    LoggingConfig,
    NotificationConfig,
    SetSuggestionFeatureConfigOperationMetadata,
    SetSuggestionFeatureConfigRequest,
    UpdateConversationProfileRequest,
)
from .document import (
    CreateDocumentRequest,
    DeleteDocumentRequest,
    Document,
    ExportOperationMetadata,
    GetDocumentRequest,
    ImportDocumentsRequest,
    ImportDocumentsResponse,
    ImportDocumentTemplate,
    KnowledgeOperationMetadata,
    ListDocumentsRequest,
    ListDocumentsResponse,
    ReloadDocumentRequest,
    UpdateDocumentRequest,
)
from .entity_type import (
    BatchCreateEntitiesRequest,
    BatchDeleteEntitiesRequest,
    BatchDeleteEntityTypesRequest,
    BatchUpdateEntitiesRequest,
    BatchUpdateEntityTypesRequest,
    BatchUpdateEntityTypesResponse,
    CreateEntityTypeRequest,
    DeleteEntityTypeRequest,
    EntityType,
    EntityTypeBatch,
    GetEntityTypeRequest,
    ListEntityTypesRequest,
    ListEntityTypesResponse,
    UpdateEntityTypeRequest,
)
from .environment import (
    CreateEnvironmentRequest,
    DeleteEnvironmentRequest,
    Environment,
    EnvironmentHistory,
    GetEnvironmentHistoryRequest,
    GetEnvironmentRequest,
    ListEnvironmentsRequest,
    ListEnvironmentsResponse,
    TextToSpeechSettings,
    UpdateEnvironmentRequest,
)
from .fulfillment import (
    Fulfillment,
    GetFulfillmentRequest,
    UpdateFulfillmentRequest,
)
from .gcs import (
    GcsDestination,
    GcsSource,
    GcsSources,
)
from .human_agent_assistant_event import (
    HumanAgentAssistantEvent,
)
from .intent import (
    BatchDeleteIntentsRequest,
    BatchUpdateIntentsRequest,
    BatchUpdateIntentsResponse,
    CreateIntentRequest,
    DeleteIntentRequest,
    GetIntentRequest,
    Intent,
    IntentBatch,
    ListIntentsRequest,
    ListIntentsResponse,
    UpdateIntentRequest,
    IntentView,
)
from .knowledge_base import (
    CreateKnowledgeBaseRequest,
    DeleteKnowledgeBaseRequest,
    GetKnowledgeBaseRequest,
    KnowledgeBase,
    ListKnowledgeBasesRequest,
    ListKnowledgeBasesResponse,
    UpdateKnowledgeBaseRequest,
)
from .participant import (
    AnalyzeContentRequest,
    AnalyzeContentResponse,
    AnnotatedMessagePart,
    ArticleAnswer,
    AssistQueryParameters,
    AutomatedAgentReply,
    CompileSuggestionRequest,
    CompileSuggestionResponse,
    CreateParticipantRequest,
    DtmfParameters,
    FaqAnswer,
    GetParticipantRequest,
    InputTextConfig,
    ListParticipantsRequest,
    ListParticipantsResponse,
    ListSuggestionsRequest,
    ListSuggestionsResponse,
    Message,
    MessageAnnotation,
    OutputAudio,
    Participant,
    ResponseMessage,
    SmartReplyAnswer,
    StreamingAnalyzeContentRequest,
    StreamingAnalyzeContentResponse,
    SuggestArticlesRequest,
    SuggestArticlesResponse,
    SuggestFaqAnswersRequest,
    SuggestFaqAnswersResponse,
    Suggestion,
    SuggestionFeature,
    SuggestionResult,
    SuggestSmartRepliesRequest,
    SuggestSmartRepliesResponse,
    UpdateParticipantRequest,
)
from .session import (
    DetectIntentRequest,
    DetectIntentResponse,
    EventInput,
    KnowledgeAnswers,
    QueryInput,
    QueryParameters,
    QueryResult,
    Sentiment,
    SentimentAnalysisRequestConfig,
    SentimentAnalysisResult,
    StreamingDetectIntentRequest,
    StreamingDetectIntentResponse,
    StreamingRecognitionResult,
    TextInput,
)
from .session_entity_type import (
    CreateSessionEntityTypeRequest,
    DeleteSessionEntityTypeRequest,
    GetSessionEntityTypeRequest,
    ListSessionEntityTypesRequest,
    ListSessionEntityTypesResponse,
    SessionEntityType,
    UpdateSessionEntityTypeRequest,
)
from .validation_result import (
    ValidationError,
    ValidationResult,
)
from .version import (
    CreateVersionRequest,
    DeleteVersionRequest,
    GetVersionRequest,
    ListVersionsRequest,
    ListVersionsResponse,
    UpdateVersionRequest,
    Version,
)
from .webhook import (
    OriginalDetectIntentRequest,
    WebhookRequest,
    WebhookResponse,
)

__all__ = (
    "Agent",
    "DeleteAgentRequest",
    "ExportAgentRequest",
    "ExportAgentResponse",
    "GetAgentRequest",
    "GetValidationResultRequest",
    "ImportAgentRequest",
    "RestoreAgentRequest",
    "SearchAgentsRequest",
    "SearchAgentsResponse",
    "SetAgentRequest",
    "SubAgent",
    "TrainAgentRequest",
    "AgentAssistantFeedback",
    "AgentAssistantRecord",
    "AnswerFeedback",
    "AnswerRecord",
    "GetAnswerRecordRequest",
    "ListAnswerRecordsRequest",
    "ListAnswerRecordsResponse",
    "UpdateAnswerRecordRequest",
    "InputAudioConfig",
    "OutputAudioConfig",
    "SpeechContext",
    "SpeechToTextConfig",
    "SpeechWordInfo",
    "SynthesizeSpeechConfig",
    "TelephonyDtmfEvents",
    "VoiceSelectionParams",
    "AudioEncoding",
    "OutputAudioEncoding",
    "SpeechModelVariant",
    "SsmlVoiceGender",
    "TelephonyDtmf",
    "Context",
    "CreateContextRequest",
    "DeleteAllContextsRequest",
    "DeleteContextRequest",
    "GetContextRequest",
    "ListContextsRequest",
    "ListContextsResponse",
    "UpdateContextRequest",
    "BatchCreateMessagesRequest",
    "BatchCreateMessagesResponse",
    "CompleteConversationRequest",
    "Conversation",
    "ConversationPhoneNumber",
    "CreateConversationRequest",
    "CreateMessageRequest",
    "GetConversationRequest",
    "ListConversationsRequest",
    "ListConversationsResponse",
    "ListMessagesRequest",
    "ListMessagesResponse",
    "ConversationEvent",
    "AutomatedAgentConfig",
    "ClearSuggestionFeatureConfigOperationMetadata",
    "ClearSuggestionFeatureConfigRequest",
    "ConversationProfile",
    "CreateConversationProfileRequest",
    "DeleteConversationProfileRequest",
    "GetConversationProfileRequest",
    "HumanAgentAssistantConfig",
    "HumanAgentHandoffConfig",
    "ListConversationProfilesRequest",
    "ListConversationProfilesResponse",
    "LoggingConfig",
    "NotificationConfig",
    "SetSuggestionFeatureConfigOperationMetadata",
    "SetSuggestionFeatureConfigRequest",
    "UpdateConversationProfileRequest",
    "CreateDocumentRequest",
    "DeleteDocumentRequest",
    "Document",
    "ExportOperationMetadata",
    "GetDocumentRequest",
    "ImportDocumentsRequest",
    "ImportDocumentsResponse",
    "ImportDocumentTemplate",
    "KnowledgeOperationMetadata",
    "ListDocumentsRequest",
    "ListDocumentsResponse",
    "ReloadDocumentRequest",
    "UpdateDocumentRequest",
    "BatchCreateEntitiesRequest",
    "BatchDeleteEntitiesRequest",
    "BatchDeleteEntityTypesRequest",
    "BatchUpdateEntitiesRequest",
    "BatchUpdateEntityTypesRequest",
    "BatchUpdateEntityTypesResponse",
    "CreateEntityTypeRequest",
    "DeleteEntityTypeRequest",
    "EntityType",
    "EntityTypeBatch",
    "GetEntityTypeRequest",
    "ListEntityTypesRequest",
    "ListEntityTypesResponse",
    "UpdateEntityTypeRequest",
    "CreateEnvironmentRequest",
    "DeleteEnvironmentRequest",
    "Environment",
    "EnvironmentHistory",
    "GetEnvironmentHistoryRequest",
    "GetEnvironmentRequest",
    "ListEnvironmentsRequest",
    "ListEnvironmentsResponse",
    "TextToSpeechSettings",
    "UpdateEnvironmentRequest",
    "Fulfillment",
    "GetFulfillmentRequest",
    "UpdateFulfillmentRequest",
    "GcsDestination",
    "GcsSource",
    "GcsSources",
    "HumanAgentAssistantEvent",
    "BatchDeleteIntentsRequest",
    "BatchUpdateIntentsRequest",
    "BatchUpdateIntentsResponse",
    "CreateIntentRequest",
    "DeleteIntentRequest",
    "GetIntentRequest",
    "Intent",
    "IntentBatch",
    "ListIntentsRequest",
    "ListIntentsResponse",
    "UpdateIntentRequest",
    "IntentView",
    "CreateKnowledgeBaseRequest",
    "DeleteKnowledgeBaseRequest",
    "GetKnowledgeBaseRequest",
    "KnowledgeBase",
    "ListKnowledgeBasesRequest",
    "ListKnowledgeBasesResponse",
    "UpdateKnowledgeBaseRequest",
    "AnalyzeContentRequest",
    "AnalyzeContentResponse",
    "AnnotatedMessagePart",
    "ArticleAnswer",
    "AssistQueryParameters",
    "AutomatedAgentReply",
    "CompileSuggestionRequest",
    "CompileSuggestionResponse",
    "CreateParticipantRequest",
    "DtmfParameters",
    "FaqAnswer",
    "GetParticipantRequest",
    "InputTextConfig",
    "ListParticipantsRequest",
    "ListParticipantsResponse",
    "ListSuggestionsRequest",
    "ListSuggestionsResponse",
    "Message",
    "MessageAnnotation",
    "OutputAudio",
    "Participant",
    "ResponseMessage",
    "SmartReplyAnswer",
    "StreamingAnalyzeContentRequest",
    "StreamingAnalyzeContentResponse",
    "SuggestArticlesRequest",
    "SuggestArticlesResponse",
    "SuggestFaqAnswersRequest",
    "SuggestFaqAnswersResponse",
    "Suggestion",
    "SuggestionFeature",
    "SuggestionResult",
    "SuggestSmartRepliesRequest",
    "SuggestSmartRepliesResponse",
    "UpdateParticipantRequest",
    "DetectIntentRequest",
    "DetectIntentResponse",
    "EventInput",
    "KnowledgeAnswers",
    "QueryInput",
    "QueryParameters",
    "QueryResult",
    "Sentiment",
    "SentimentAnalysisRequestConfig",
    "SentimentAnalysisResult",
    "StreamingDetectIntentRequest",
    "StreamingDetectIntentResponse",
    "StreamingRecognitionResult",
    "TextInput",
    "CreateSessionEntityTypeRequest",
    "DeleteSessionEntityTypeRequest",
    "GetSessionEntityTypeRequest",
    "ListSessionEntityTypesRequest",
    "ListSessionEntityTypesResponse",
    "SessionEntityType",
    "UpdateSessionEntityTypeRequest",
    "ValidationError",
    "ValidationResult",
    "CreateVersionRequest",
    "DeleteVersionRequest",
    "GetVersionRequest",
    "ListVersionsRequest",
    "ListVersionsResponse",
    "UpdateVersionRequest",
    "Version",
    "OriginalDetectIntentRequest",
    "WebhookRequest",
    "WebhookResponse",
)

==> google-cloud-dialogflow-2.17.0.tar.gz: google-cloud-dialogflow-2.17.0/google/cloud/dialogflow_v2beta1/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .agent import (
    Agent,
    DeleteAgentRequest,
    ExportAgentRequest,
    ExportAgentResponse,
    GetAgentRequest,
    GetValidationResultRequest,
    ImportAgentRequest,
    RestoreAgentRequest,
    SearchAgentsRequest,
    SearchAgentsResponse,
    SetAgentRequest,
    SubAgent,
    TrainAgentRequest,
)
from .answer_record import (
    AgentAssistantFeedback,
    AgentAssistantRecord,
    AnswerFeedback,
    AnswerRecord,
    GetAnswerRecordRequest,
    ListAnswerRecordsRequest,
    ListAnswerRecordsResponse,
    UpdateAnswerRecordRequest,
)
from .audio_config import (
    AudioEncoding,
    InputAudioConfig,
    OutputAudioConfig,
    OutputAudioEncoding,
    SpeechContext,
    SpeechModelVariant,
    SpeechToTextConfig,
    SpeechWordInfo,
    SsmlVoiceGender,
    SynthesizeSpeechConfig,
    TelephonyDtmf,
    TelephonyDtmfEvents,
    VoiceSelectionParams,
)
from .context import (
    Context,
    CreateContextRequest,
    DeleteAllContextsRequest,
    DeleteContextRequest,
    GetContextRequest,
    ListContextsRequest,
    ListContextsResponse,
    UpdateContextRequest,
)
from .conversation import (
    BatchCreateMessagesRequest,
    BatchCreateMessagesResponse,
    CompleteConversationRequest,
    Conversation,
    ConversationPhoneNumber,
    CreateConversationRequest,
    CreateMessageRequest,
    GetConversationRequest,
    ListConversationsRequest,
    ListConversationsResponse,
    ListMessagesRequest,
    ListMessagesResponse,
    SuggestConversationSummaryRequest,
    SuggestConversationSummaryResponse,
)
from .conversation_event import ConversationEvent
from .conversation_profile import (
    AutomatedAgentConfig,
    ClearSuggestionFeatureConfigOperationMetadata,
    ClearSuggestionFeatureConfigRequest,
    ConversationProfile,
    CreateConversationProfileRequest,
    DeleteConversationProfileRequest,
    GetConversationProfileRequest,
    HumanAgentAssistantConfig,
    HumanAgentHandoffConfig,
    ListConversationProfilesRequest,
    ListConversationProfilesResponse,
    LoggingConfig,
    NotificationConfig,
    SetSuggestionFeatureConfigOperationMetadata,
    SetSuggestionFeatureConfigRequest,
    UpdateConversationProfileRequest,
)
from .document import (
    CreateDocumentRequest,
    DeleteDocumentRequest,
    Document,
    ExportOperationMetadata,
    GetDocumentRequest,
    ImportDocumentsRequest,
    ImportDocumentsResponse,
    ImportDocumentTemplate,
    KnowledgeOperationMetadata,
    ListDocumentsRequest,
    ListDocumentsResponse,
    ReloadDocumentRequest,
    UpdateDocumentRequest,
)
from .entity_type import (
    BatchCreateEntitiesRequest,
    BatchDeleteEntitiesRequest,
    BatchDeleteEntityTypesRequest,
    BatchUpdateEntitiesRequest,
    BatchUpdateEntityTypesRequest,
    BatchUpdateEntityTypesResponse,
    CreateEntityTypeRequest,
    DeleteEntityTypeRequest,
    EntityType,
    EntityTypeBatch,
    GetEntityTypeRequest,
    ListEntityTypesRequest,
    ListEntityTypesResponse,
    UpdateEntityTypeRequest,
)
from .environment import (
    CreateEnvironmentRequest,
    DeleteEnvironmentRequest,
    Environment,
    EnvironmentHistory,
    GetEnvironmentHistoryRequest,
    GetEnvironmentRequest,
    ListEnvironmentsRequest,
    ListEnvironmentsResponse,
    TextToSpeechSettings,
    UpdateEnvironmentRequest,
)
from .fulfillment import Fulfillment, GetFulfillmentRequest, UpdateFulfillmentRequest
from .gcs import GcsDestination, GcsSource, GcsSources
from .human_agent_assistant_event import HumanAgentAssistantEvent
from .intent import (
    BatchDeleteIntentsRequest,
    BatchUpdateIntentsRequest,
    BatchUpdateIntentsResponse,
    CreateIntentRequest,
    DeleteIntentRequest,
    GetIntentRequest,
    Intent,
    IntentBatch,
    IntentView,
    ListIntentsRequest,
    ListIntentsResponse,
    UpdateIntentRequest,
)
from .knowledge_base import (
    CreateKnowledgeBaseRequest,
    DeleteKnowledgeBaseRequest,
    GetKnowledgeBaseRequest,
    KnowledgeBase,
    ListKnowledgeBasesRequest,
    ListKnowledgeBasesResponse,
    UpdateKnowledgeBaseRequest,
)
from .participant import (
    AnalyzeContentRequest,
    AnalyzeContentResponse,
    AnnotatedMessagePart,
    ArticleAnswer,
    AssistQueryParameters,
    AudioInput,
    AutomatedAgentReply,
    CompileSuggestionRequest,
    CompileSuggestionResponse,
    CreateParticipantRequest,
    DtmfParameters,
    FaqAnswer,
    GetParticipantRequest,
    InputTextConfig,
    ListParticipantsRequest,
    ListParticipantsResponse,
    ListSuggestionsRequest,
    ListSuggestionsResponse,
    Message,
    MessageAnnotation,
    OutputAudio,
    Participant,
    ResponseMessage,
    SmartReplyAnswer,
    StreamingAnalyzeContentRequest,
    StreamingAnalyzeContentResponse,
    SuggestArticlesRequest,
    SuggestArticlesResponse,
    SuggestFaqAnswersRequest,
    SuggestFaqAnswersResponse,
    Suggestion,
    SuggestionFeature,
    SuggestionResult,
    SuggestSmartRepliesRequest,
    SuggestSmartRepliesResponse,
    UpdateParticipantRequest,
)
from .session import (
    DetectIntentRequest,
    DetectIntentResponse,
    EventInput,
    KnowledgeAnswers,
    QueryInput,
    QueryParameters,
    QueryResult,
    Sentiment,
    SentimentAnalysisRequestConfig,
    SentimentAnalysisResult,
    StreamingDetectIntentRequest,
    StreamingDetectIntentResponse,
    StreamingRecognitionResult,
    TextInput,
)
from .session_entity_type import (
    CreateSessionEntityTypeRequest,
    DeleteSessionEntityTypeRequest,
    GetSessionEntityTypeRequest,
    ListSessionEntityTypesRequest,
    ListSessionEntityTypesResponse,
    SessionEntityType,
    UpdateSessionEntityTypeRequest,
)
from .validation_result import ValidationError, ValidationResult
from .version import (
    CreateVersionRequest,
    DeleteVersionRequest,
    GetVersionRequest,
    ListVersionsRequest,
    ListVersionsResponse,
    UpdateVersionRequest,
    Version,
)
from .webhook import OriginalDetectIntentRequest, WebhookRequest, WebhookResponse

__all__ = (
    "Agent",
    "DeleteAgentRequest",
    "ExportAgentRequest",
    "ExportAgentResponse",
    "GetAgentRequest",
    "GetValidationResultRequest",
    "ImportAgentRequest",
    "RestoreAgentRequest",
    "SearchAgentsRequest",
    "SearchAgentsResponse",
    "SetAgentRequest",
    "SubAgent",
    "TrainAgentRequest",
    "AgentAssistantFeedback",
    "AgentAssistantRecord",
    "AnswerFeedback",
    "AnswerRecord",
    "GetAnswerRecordRequest",
    "ListAnswerRecordsRequest",
    "ListAnswerRecordsResponse",
    "UpdateAnswerRecordRequest",
    "InputAudioConfig",
    "OutputAudioConfig",
    "SpeechContext",
    "SpeechToTextConfig",
    "SpeechWordInfo",
    "SynthesizeSpeechConfig",
    "TelephonyDtmfEvents",
    "VoiceSelectionParams",
    "AudioEncoding",
    "OutputAudioEncoding",
    "SpeechModelVariant",
    "SsmlVoiceGender",
    "TelephonyDtmf",
    "Context",
    "CreateContextRequest",
    "DeleteAllContextsRequest",
    "DeleteContextRequest",
    "GetContextRequest",
    "ListContextsRequest",
    "ListContextsResponse",
    "UpdateContextRequest",
    "BatchCreateMessagesRequest",
    "BatchCreateMessagesResponse",
    "CompleteConversationRequest",
    "Conversation",
    "ConversationPhoneNumber",
    "CreateConversationRequest",
    "CreateMessageRequest",
    "GetConversationRequest",
    "ListConversationsRequest",
    "ListConversationsResponse",
    "ListMessagesRequest",
    "ListMessagesResponse",
    "SuggestConversationSummaryRequest",
    "SuggestConversationSummaryResponse",
    "ConversationEvent",
    "AutomatedAgentConfig",
    "ClearSuggestionFeatureConfigOperationMetadata",
    "ClearSuggestionFeatureConfigRequest",
    "ConversationProfile",
    "CreateConversationProfileRequest",
    "DeleteConversationProfileRequest",
    "GetConversationProfileRequest",
    "HumanAgentAssistantConfig",
    "HumanAgentHandoffConfig",
    "ListConversationProfilesRequest",
    "ListConversationProfilesResponse",
    "LoggingConfig",
    "NotificationConfig",
    "SetSuggestionFeatureConfigOperationMetadata",
    "SetSuggestionFeatureConfigRequest",
    "UpdateConversationProfileRequest",
    "CreateDocumentRequest",
    "DeleteDocumentRequest",
    "Document",
    "ExportOperationMetadata",
    "GetDocumentRequest",
    "ImportDocumentsRequest",
    "ImportDocumentsResponse",
    "ImportDocumentTemplate",
    "KnowledgeOperationMetadata",
    "ListDocumentsRequest",
    "ListDocumentsResponse",
    "ReloadDocumentRequest",
    "UpdateDocumentRequest",
    "BatchCreateEntitiesRequest",
    "BatchDeleteEntitiesRequest",
    "BatchDeleteEntityTypesRequest",
    "BatchUpdateEntitiesRequest",
    "BatchUpdateEntityTypesRequest",
    "BatchUpdateEntityTypesResponse",
    "CreateEntityTypeRequest",
    "DeleteEntityTypeRequest",
    "EntityType",
    "EntityTypeBatch",
    "GetEntityTypeRequest",
    "ListEntityTypesRequest",
    "ListEntityTypesResponse",
    "UpdateEntityTypeRequest",
    "CreateEnvironmentRequest",
    "DeleteEnvironmentRequest",
    "Environment",
    "EnvironmentHistory",
    "GetEnvironmentHistoryRequest",
    "GetEnvironmentRequest",
    "ListEnvironmentsRequest",
    "ListEnvironmentsResponse",
    "TextToSpeechSettings",
    "UpdateEnvironmentRequest",
    "Fulfillment",
    "GetFulfillmentRequest",
    "UpdateFulfillmentRequest",
    "GcsDestination",
    "GcsSource",
    "GcsSources",
    "HumanAgentAssistantEvent",
    "BatchDeleteIntentsRequest",
    "BatchUpdateIntentsRequest",
    "BatchUpdateIntentsResponse",
    "CreateIntentRequest",
    "DeleteIntentRequest",
    "GetIntentRequest",
    "Intent",
    "IntentBatch",
    "ListIntentsRequest",
    "ListIntentsResponse",
    "UpdateIntentRequest",
    "IntentView",
    "CreateKnowledgeBaseRequest",
    "DeleteKnowledgeBaseRequest",
    "GetKnowledgeBaseRequest",
    "KnowledgeBase",
    "ListKnowledgeBasesRequest",
    "ListKnowledgeBasesResponse",
    "UpdateKnowledgeBaseRequest",
    "AnalyzeContentRequest",
    "AnalyzeContentResponse",
    "AnnotatedMessagePart",
    "ArticleAnswer",
    "AssistQueryParameters",
    "AudioInput",
    "AutomatedAgentReply",
    "CompileSuggestionRequest",
    "CompileSuggestionResponse",
    "CreateParticipantRequest",
    "DtmfParameters",
    "FaqAnswer",
    "GetParticipantRequest",
    "InputTextConfig",
    "ListParticipantsRequest",
    "ListParticipantsResponse",
    "ListSuggestionsRequest",
    "ListSuggestionsResponse",
    "Message",
    "MessageAnnotation",
    "OutputAudio",
    "Participant",
    "ResponseMessage",
    "SmartReplyAnswer",
    "StreamingAnalyzeContentRequest",
    "StreamingAnalyzeContentResponse",
    "SuggestArticlesRequest",
    "SuggestArticlesResponse",
    "SuggestFaqAnswersRequest",
    "SuggestFaqAnswersResponse",
    "Suggestion",
    "SuggestionFeature",
    "SuggestionResult",
    "SuggestSmartRepliesRequest",
    "SuggestSmartRepliesResponse",
    "UpdateParticipantRequest",
    "DetectIntentRequest",
    "DetectIntentResponse",
    "EventInput",
    "KnowledgeAnswers",
    "QueryInput",
    "QueryParameters",
    "QueryResult",
    "Sentiment",
    "SentimentAnalysisRequestConfig",
    "SentimentAnalysisResult",
    "StreamingDetectIntentRequest",
    "StreamingDetectIntentResponse",
    "StreamingRecognitionResult",
    "TextInput",
    "CreateSessionEntityTypeRequest",
    "DeleteSessionEntityTypeRequest",
    "GetSessionEntityTypeRequest",
    "ListSessionEntityTypesRequest",
    "ListSessionEntityTypesResponse",
    "SessionEntityType",
    "UpdateSessionEntityTypeRequest",
    "ValidationError",
    "ValidationResult",
    "CreateVersionRequest",
    "DeleteVersionRequest",
    "GetVersionRequest",
    "ListVersionsRequest",
    "ListVersionsResponse",
    "UpdateVersionRequest",
    "Version",
    "OriginalDetectIntentRequest",
    "WebhookRequest",
    "WebhookResponse",
)
